---
name: Blackjax Meeting
about: Blackjax public meeting
title: '👋 Blackjax Meeting - {{ MONTH }}'
labels: meeting
assignees: ''
---

Hello! This is an issue to track the next Blackjax meeting. Here's some relevant information:

- **Date**: Paris time at **5:00PM on the FIRST Friday of the month**
- [**Google Calendar Link**](https://calendar.google.com/calendar/u/0?cid=MDVlMzVkODQyYzJmZDc1YjkxZjFmNTExYWJlNmVjYzhiYjM2NDk3OWYxMTFjOWVkNzhkYzliN2Y3MDk3YTc0M0Bncm91cC5jYWxlbmRhci5nb29nbGUuY29t).
- [**Video Link**](https://meet.google.com/ack-uozu-xww)

These meetings are public and can be attended by anyone. If you'd like to discuss something at the meeting, we kindly ask you to comment on this issue beforehand.
